==> trilinos-15.1.1-1-x86_64.pkg.tar.zst: usr/include/MueLu_ThresholdAFilterFactory_decl.hpp <==
// @HEADER
//
// ***********************************************************************
//
//        MueLu: A package for multigrid based preconditioning
//                  Copyright 2012 Sandia Corporation
//
// Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
// the U.S. Government retains certain rights in this software.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
// 1. Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
//
// 3. Neither the name of the Corporation nor the names of the
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY SANDIA CORPORATION "AS IS" AND ANY
// EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
// PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL SANDIA CORPORATION OR THE
// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
// PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
// LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
// NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
// Questions? Contact
//                    Jonathan Hu       (jhu@sandia.gov)
//                    Andrey Prokopenko (aprokop@sandia.gov)
//                    Ray Tuminaro      (rstumin@sandia.gov)
//
// ***********************************************************************
//
// @HEADER
#ifndef MUELU_THRESHOLDAFILTERFACTORY_DECL_HPP
#define MUELU_THRESHOLDAFILTERFACTORY_DECL_HPP

/*
 * MueLu_ThresholdAFilterFactory.hpp
 *
 *  Created on: 14.10.2011
 *      Author: tobias
 */

#include "MueLu_ConfigDefs.hpp"
#include "MueLu_SingleLevelFactoryBase.hpp"
#include "MueLu_ThresholdAFilterFactory_fwd.hpp"

namespace MueLu {

/*!
  @class ThresholdAFilterFactory class.
  @brief Factory for building a thresholded operator.

*/

template <class Scalar        = DefaultScalar,
          class LocalOrdinal  = DefaultLocalOrdinal,
          class GlobalOrdinal = DefaultGlobalOrdinal,
          class Node          = DefaultNode>
class ThresholdAFilterFactory : public SingleLevelFactoryBase {
#undef MUELU_THRESHOLDAFILTERFACTORY_SHORT
#include "MueLu_UseShortNames.hpp"

 public:
  //! @name Constructors/Destructors.
  //@{

  //! Constructor.
  ThresholdAFilterFactory(const std::string& ename, const Scalar threshold, const bool keepDiagonal = true, const GlobalOrdinal expectedNNZperRow = -1);

  //! Input
  //@{

  void DeclareInput(Level& currentLevel) const;

  //@}

  //@{
  //! @name Build methods.

  //! Build an object with this factory.
  void Build(Level& currentLevel) const;

  //@}

 private:
  std::string varName_;     ///< name of input and output variable
  const Scalar threshold_;  ///< threshold parameter
  const bool keepDiagonal_;
  const GlobalOrdinal expectedNNZperRow_;

};  // class ThresholdAFilterFactory

}  // namespace MueLu

#define MUELU_THRESHOLDAFILTERFACTORY_SHORT
#endif  // MUELU_THRESHOLDAFILTERFACTORY_DECL_HPP

==> trilinos-16.1.0-2-x86_64.pkg.tar.zst: usr/include/MueLu_ThresholdAFilterFactory_decl.hpp <==
// @HEADER
// *****************************************************************************
//        MueLu: A package for multigrid based preconditioning
//
// Copyright 2012 NTESS and the MueLu contributors.
// SPDX-License-Identifier: BSD-3-Clause
// *****************************************************************************
// @HEADER

#ifndef MUELU_THRESHOLDAFILTERFACTORY_DECL_HPP
#define MUELU_THRESHOLDAFILTERFACTORY_DECL_HPP

/*
 * MueLu_ThresholdAFilterFactory.hpp
 *
 *  Created on: 14.10.2011
 *      Author: tobias
 */

#include "MueLu_ConfigDefs.hpp"
#include "MueLu_SingleLevelFactoryBase.hpp"
#include "MueLu_ThresholdAFilterFactory_fwd.hpp"
#include "Teuchos_ScalarTraits.hpp"

namespace MueLu {

/*!
  @class ThresholdAFilterFactory class.
  @brief Factory for building a thresholded operator.

*/

template <class Scalar        = DefaultScalar,
          class LocalOrdinal  = DefaultLocalOrdinal,
          class GlobalOrdinal = DefaultGlobalOrdinal,
          class Node          = DefaultNode>
class ThresholdAFilterFactory : public SingleLevelFactoryBase {
#undef MUELU_THRESHOLDAFILTERFACTORY_SHORT
#include "MueLu_UseShortNames.hpp"

  using magnitudeType = typename Teuchos::ScalarTraits<Scalar>::magnitudeType;

 public:
  //! @name Constructors/Destructors.
  //@{

  //! Constructor.
  ThresholdAFilterFactory(const std::string& ename, const magnitudeType threshold, const bool keepDiagonal = true, const GlobalOrdinal expectedNNZperRow = -1);

  //! Input
  //@{

  void DeclareInput(Level& currentLevel) const;

  //@}

  //@{
  //! @name Build methods.

  //! Build an object with this factory.
  void Build(Level& currentLevel) const;

  //@}

 private:
  std::string varName_;            ///< name of input and output variable
  const magnitudeType threshold_;  ///< threshold parameter
  const bool keepDiagonal_;
  const GlobalOrdinal expectedNNZperRow_;

};  // class ThresholdAFilterFactory

}  // namespace MueLu

#define MUELU_THRESHOLDAFILTERFACTORY_SHORT
#endif  // MUELU_THRESHOLDAFILTERFACTORY_DECL_HPP
